@@ -71,7 +71,7 @@ void TQTrayLabel::initialize(void)
   mBalloon->setFont(TQToolTip::font());
   mBalloon->setPalette(TQToolTip::palette());
   mBalloon->setAlignment(TQt::AlignLeft | TQt::AlignTop);
-  mBalloon->setAutoMask(FALSE);
+  mBalloon->setAutoMask(false);
   mBalloon->setAutoResize(true);
   setAlignment(TQt::AlignCenter);
   setBackgroundMode(X11ParentRelative);
@@ -795,13 +795,13 @@ bool TQTrayLabel::x11EventFilter(XEvent *ev)
     return true; // Dont process this again
   }
 
-  if (mDockedWindow != None || event->type != MapNotify) return FALSE;
+  if (mDockedWindow != None || event->type != MapNotify) return false;
 
   TRACE("%s Will analyze window 0x%x", me(), (int)((XMapEvent *)event)->window);
   // Check if this window is the soulmate we are looking for
   Display *display = TQPaintDevice::x11AppDisplay();
   Window w = XmuClientWindow(display, ((XMapEvent *) event)->window);
-  if (!isNormalWindow(display, w)) return FALSE;
+  if (!isNormalWindow(display, w)) return false;
   if (!analyzeWindow(display, w, mPid, TQFileInfo(appName()).fileName().local8Bit()))
   {
     return false;
